Module org.refcodes.mixin
Package org.refcodes.mixin
Interface StatusCodeAccessor.StatusCodeBuilder<SC,B extends StatusCodeAccessor.StatusCodeBuilder<SC,B>>
- Type Parameters:
SC- The type of the status code to be used.B- The builder to return in order to be able to apply multiple build operations.
- Enclosing interface:
- StatusCodeAccessor<SC>
public static interface StatusCodeAccessor.StatusCodeBuilder<SC,B extends StatusCodeAccessor.StatusCodeBuilder<SC,B>>
Provides a builder method for a status code property returning the
builder for applying multiple build operations.
-
Method Summary
Modifier and TypeMethodDescriptionwithStatusCode(String aStatusCode) Sets the status code for the status code property.
-
Method Details
-
withStatusCode
Sets the status code for the status code property.- Parameters:
aStatusCode- The status code to be stored by the status code property.- Returns:
- The builder for applying multiple build operations.
-