Interface StatusCodeAccessor.StatusCodeMutator<SC>
- Type Parameters:
SC- The type of the status code property.
- All Known Subinterfaces:
StatusCodeAccessor.StatusCodeProperty<SC>
- Enclosing interface:
StatusCodeAccessor<SC>
public static interface StatusCodeAccessor.StatusCodeMutator<SC>
Extends the
StatusCodeAccessor with a setter method.-
Method Summary
Modifier and TypeMethodDescriptionvoidsetStatusCode(SC aStatusCode) Sets the status code for the status code property.
-
Method Details
-
setStatusCode
Sets the status code for the status code property.- Parameters:
aStatusCode- The status code to be stored by the status code property.
-